@@ -3,10 +3,9 @@ from typing import Optional, Tuple
 
 import numpy as np
 
-import k4a_module
-
 from .config import ColorResolution, DepthMode
 from .errors import K4AException, _verify_error
+from .module import k4a_module
 
 
 class CalibrationType(IntEnum):
@@ -54,15 +53,19 @@ class Calibration:
         target_camera: CalibrationType,
     ) -> Tuple[float, float, float]:
         """
-            Transform a 3d point of a source coordinate system into a 3d
-            point of the target coordinate system.
-            :param source_point_3d  The 3D coordinates in millimeters representing a point in source_camera.
-            :param source_camera    The current camera.
-            :param target_camera    The target camera.
-            :return                 The 3D coordinates in millimeters representing a point in target camera.
+        Transform a 3d point of a source coordinate system into a 3d
+        point of the target coordinate system.
+        :param source_point_3d  The 3D coordinates in millimeters representing a point in source_camera.
+        :param source_camera    The current camera.
+        :param target_camera    The target camera.
+        :return                 The 3D coordinates in millimeters representing a point in target camera.
         """
         res, target_point_3d = k4a_module.calibration_3d_to_3d(
-            self._calibration_handle, self.thread_safe, source_point_3d, source_camera, target_camera,
+            self._calibration_handle,
+            self.thread_safe,
+            source_point_3d,
+            source_camera,
+            target_camera,
         )
 
         _verify_error(res)
@@ -82,16 +85,21 @@ class Calibration:
         target_camera: CalibrationType,
     ) -> Tuple[float, float, float]:
         """
-            Transform a 3d point of a source coordinate system into a 3d
-            point of the target coordinate system.
-            :param source_pixel_2d    The 2D coordinates in px of source_camera color_image.
-            :param source_depth       Depth in mm
-            :param source_camera      The current camera.
-            :param target_camera      The target camera.
-            :return                   The 3D coordinates in mm representing a point in target camera.
+        Transform a 3d point of a source coordinate system into a 3d
+        point of the target coordinate system.
+        :param source_pixel_2d    The 2D coordinates in px of source_camera color_image.
+        :param source_depth       Depth in mm
+        :param source_camera      The current camera.
+        :param target_camera      The target camera.
+        :return                   The 3D coordinates in mm representing a point in target camera.
         """
         res, valid, target_point_3d = k4a_module.calibration_2d_to_3d(
-            self._calibration_handle, self.thread_safe, source_pixel_2d, source_depth, source_camera, target_camera,
+            self._calibration_handle,
+            self.thread_safe,
+            source_pixel_2d,
+            source_depth,
+            source_camera,
+            target_camera,
         )
 
         _verify_error(res)
@@ -108,7 +116,7 @@ class Calibration:
         target_camera: Optional[CalibrationType] = None,
     ):
         """
-            Transform a 2d pixel to a 3d point of the target coordinate system.
+        Transform a 2d pixel to a 3d point of the target coordinate system.
         """
         if target_camera is None:
             target_camera = source_camera
@@ -121,15 +129,19 @@ class Calibration:
         target_camera: CalibrationType,
     ) -> Tuple[float, float]:
         """
-            Transform a 3d point of a source coordinate system into a 3d
-            point of the target coordinate system.
-            :param source_point_3d    The 3D coordinates in mm of source_camera.
-            :param source_camera      The current camera.
-            :param target_camera      The target camera.
-            :return                   The 3D coordinates in mm representing a point in target camera.
+        Transform a 3d point of a source coordinate system into a 3d
+        point of the target coordinate system.
+        :param source_point_3d    The 3D coordinates in mm of source_camera.
+        :param source_camera      The current camera.
+        :param target_camera      The target camera.
+        :return                   The 3D coordinates in mm representing a point in target camera.
         """
         res, valid, target_px_2d = k4a_module.calibration_3d_to_2d(
-            self._calibration_handle, self.thread_safe, source_point_3d, source_camera, target_camera,
+            self._calibration_handle,
+            self.thread_safe,
+            source_point_3d,
+            source_camera,
+            target_camera,
         )
 
         _verify_error(res)
@@ -145,7 +157,7 @@ class Calibration:
         target_camera: Optional[CalibrationType] = None,
     ):
         """
-            Transform a 3d point to a 2d pixel of the target coordinate system.
+        Transform a 3d point to a 2d pixel of the target coordinate system.
         """
         if target_camera is None:
             target_camera = source_camera
