@@ -2,11 +2,10 @@ from typing import Optional
 
 import numpy as np
 
-import k4a_module
-
 from .calibration import Calibration
 from .config import ImageFormat
 from .errors import K4AException
+from .module import k4a_module
 from .transformation import (
     color_image_to_depth_camera,
     depth_image_to_color_camera,
@@ -139,7 +138,10 @@ class PyK4ACapture:
     def depth_point_cloud(self) -> Optional[np.ndarray]:
         if self._depth_point_cloud is None and self.depth is not None:
             self._depth_point_cloud = depth_image_to_point_cloud(
-                self._depth, self._calibration, self.thread_safe, calibration_type_depth=True,
+                self._depth,
+                self._calibration,
+                self.thread_safe,
+                calibration_type_depth=True,
             )
         return self._depth_point_cloud
 
@@ -147,7 +149,10 @@ class PyK4ACapture:
     def transformed_depth_point_cloud(self) -> Optional[np.ndarray]:
         if self._transformed_depth_point_cloud is None and self.transformed_depth is not None:
             self._transformed_depth_point_cloud = depth_image_to_point_cloud(
-                self.transformed_depth, self._calibration, self.thread_safe, calibration_type_depth=False,
+                self.transformed_depth,
+                self._calibration,
+                self.thread_safe,
+                calibration_type_depth=False,
             )
         return self._transformed_depth_point_cloud
 
