@@ -9,12 +9,12 @@ if sys.version_info < (3, 8):
 else:
     from typing import TypedDict
 
-import k4a_module
-
 from .calibration import Calibration
 from .capture import PyK4ACapture
 from .config import FPS, ColorResolution, DepthMode, ImageFormat, WiredSyncMode
 from .errors import K4AException, _verify_error
+from .module import k4a_module
+from .pyk4a import ImuSample
 from .results import Result, StreamResult
 
 
@@ -53,10 +53,17 @@ class PyK4APlayback:
         if self._handle:
             self.close()
 
+    def __enter__(self):
+        self.open()
+        return self
+
+    def __exit__(self):
+        self.close()
+
     @property
     def path(self) -> Path:
         """
-            Record file path
+        Record file path
         """
         return self._path
 
@@ -87,7 +94,7 @@ class PyK4APlayback:
     @property
     def length(self) -> int:
         """
-            Record length in usec
+        Record length in usec
         """
         if self._length is None:
             self._validate_is_open()
@@ -124,7 +131,7 @@ class PyK4APlayback:
 
     def open(self) -> None:
         """
-            Open record file
+        Open record file
         """
         if self._handle:
             raise K4AException("Playback already opened")
@@ -136,7 +143,7 @@ class PyK4APlayback:
 
     def close(self):
         """
-            Close record file
+        Close record file
         """
         self._validate_is_open()
         k4a_module.playback_close(self._handle, self.thread_safe)
@@ -144,7 +151,7 @@ class PyK4APlayback:
 
     def seek(self, offset: int, origin: SeekOrigin = SeekOrigin.BEGIN) -> None:
         """
-            Seek playback pointer to specified offset
+        Seek playback pointer to specified offset
         """
         self._validate_is_open()
         result = k4a_module.playback_seek_timestamp(self._handle, self.thread_safe, offset, int(origin))
@@ -172,6 +179,12 @@ class PyK4APlayback:
             thread_safe=self.thread_safe,
         )
 
+    def get_next_imu_sample(self) -> Optional["ImuSample"]:
+        self._validate_is_open()
+        result, imu_sample = k4a_module.playback_get_next_imu_sample(self._handle, self.thread_safe)
+        self._verify_stream_error(result)
+        return imu_sample
+
     def _validate_is_open(self):
         if not self._handle:
             raise K4AException("Playback not opened.")
